(segmentation)=
# Segmentation

This section contains tutorials for segmentation [labeling](../../howtos/layers/labels).

* [Annotating segmentation with text and bounding boxes](annotate_segmentation)
